@@ -1,6 +1,6 @@
 /* aguix.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2015 Ralf Hoffmann.
+ * Copyright (C) 2001-2016 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -310,6 +310,9 @@ int AGUIX::initX()
   XA_NET_WM_WINDOW_TYPE_DIALOG = XInternAtom( dsp, "_NET_WM_WINDOW_TYPE_DIALOG", False );
   XA_NET_WM_WINDOW_TYPE_NORMAL = XInternAtom( dsp, "_NET_WM_WINDOW_TYPE_NORMAL", False );
   XA_UTF8_STRING = XInternAtom( dsp, "UTF8_STRING", False );
+  XA_NET_WM_STATE = XInternAtom( dsp, "_NET_WM_STATE", False );
+  XA_NET_WM_STATE_MAXIMIZED_HORZ = XInternAtom( dsp, "_NET_WM_STATE_MAXIMIZED_HORZ", False );
+  XA_NET_WM_STATE_MAXIMIZED_VERT = XInternAtom( dsp, "_NET_WM_STATE_MAXIMIZED_VERT", False );
 
   initOK=True;
   return 0;
@@ -2787,6 +2790,12 @@ Atom AGUIX::getAtom( atom_name_t name ) const
             return XA_NET_WM_WINDOW_TYPE_DIALOG;
         case NET_WM_WINDOW_TYPE_NORMAL:
             return XA_NET_WM_WINDOW_TYPE_NORMAL;
+        case NET_WM_STATE:
+            return XA_NET_WM_STATE;
+        case NET_WM_STATE_MAXIMIZED_HORZ:
+            return XA_NET_WM_STATE_MAXIMIZED_HORZ;
+        case NET_WM_STATE_MAXIMIZED_VERT:
+            return XA_NET_WM_STATE_MAXIMIZED_VERT;
         case UTF8_STRING:
             return XA_UTF8_STRING;
     }
@@ -3092,6 +3101,43 @@ void AGUIX::getLargestDimensionOfCurrentScreen( int *x, int *y,
     if ( height ) *height = getRootWindowHeight();
 }
 
+bool AGUIX::isValidScreenPosition( int x, int y,
+                                   int w, int h )
+{
+#ifdef HAVE_XINERAMA
+    XineramaScreenInfo *xinerama_info;
+    int number_of_xinerama_screens = 0;
+    bool found = false;
+
+    xinerama_info = XineramaQueryScreens( dsp,
+                                          &number_of_xinerama_screens );
+
+    if ( xinerama_info != NULL ) {
+        for ( int i = 0; i < number_of_xinerama_screens; i++ ) {
+            if ( x + w > xinerama_info[i].x_org &&
+                 y + h > xinerama_info[i].y_org &&
+                 x < xinerama_info[i].x_org + xinerama_info[i].width &&
+                 y < xinerama_info[i].y_org + xinerama_info[i].height ) {
+                found = true;
+                break;
+            }
+        }
+
+        XFree( xinerama_info );
+
+        return found;
+    }
+#endif
+
+    if ( x + w < 0 ) return false;
+    if ( x >= getRootWindowWidth() ) return false;
+
+    if ( y + h < 0 ) return false;
+    if ( y >= getRootWindowHeight() ) return false;
+
+    return true;
+}
+
 bool AGUIX::rerequestCut()
 {
     if ( m_last_selection_request_atom != XA_STRING ) {
