@@ -1,6 +1,6 @@
 /* aguix.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2015 Ralf Hoffmann.
+ * Copyright (C) 2001-2016 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -220,7 +220,8 @@ public:
 
     typedef enum { CLOSE_ATOM, NET_WM_NAME_ATOM, NET_WM_ICON_NAME_ATOM, TARGETS_ATOM,
                    NET_WM_WINDOW_TYPE, NET_WM_WINDOW_TYPE_DIALOG, NET_WM_WINDOW_TYPE_NORMAL,
-                   UTF8_STRING
+                   UTF8_STRING, NET_WM_STATE, NET_WM_STATE_MAXIMIZED_HORZ,
+                   NET_WM_STATE_MAXIMIZED_VERT
     } atom_name_t;
   Atom getAtom( atom_name_t name ) const;
 
@@ -293,6 +294,9 @@ public:
     void setExternalTimeoutStore( std::weak_ptr< TimeoutStore > timeout_store );
 
     void external_timeout_callback();
+
+    bool isValidScreenPosition( int x, int y,
+                                int w, int h );
 private:
   Display *dsp;
   int scr;
@@ -305,7 +309,10 @@ private:
       XA_NET_WM_WINDOW_TYPE,
       XA_NET_WM_WINDOW_TYPE_DIALOG,
       XA_NET_WM_WINDOW_TYPE_NORMAL,
-      XA_UTF8_STRING;
+      XA_UTF8_STRING,
+      XA_NET_WM_STATE,
+      XA_NET_WM_STATE_MAXIMIZED_HORZ,
+      XA_NET_WM_STATE_MAXIMIZED_VERT;
   int m_argc;
   char **m_argv;
   std::string m_classname;
