@@ -1,6 +1,6 @@
 /* awindow.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2015 Ralf Hoffmann.
+ * Copyright (C) 2001-2016 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -41,6 +41,12 @@ AWindow::AWindow( AGUIX *aguix,
   _w = ( width > 0 ) ? width : 1;
   _h = ( height > 0 ) ? height : 1;
 
+  m_open_pos_x = 0;
+  m_open_pos_y = 0;
+  m_open_max_h = false;
+  m_open_max_v = false;
+  m_force_open_position = false;
+
   _bg = _aguix->getFaces().getColor( "default-bg" );
 
   if ( _bg < 0 ) {
@@ -65,6 +71,8 @@ AWindow::AWindow( AGUIX *aguix,
   _callback_forbidden = false;
 
   m_window_type = type;
+
+  m_size_hints = NULL;
 }
 
 AGUIX *AWindow::getAGUIX() const
@@ -138,52 +146,54 @@ void AWindow::ReactMessage(Message *msg)
 
 void AWindow::setMaxSize(int mwidth,int mheight)
 {
-  XSizeHints *SizeHints;
-  Display *dsp=_aguix->getDisplay();
-  SizeHints=XAllocSizeHints();
+    Display *dsp = _aguix->getDisplay();
 
-  if ( SizeHints ) {
-      if(minw>=0) {
-          SizeHints->flags=PMaxSize|PMinSize;
-          SizeHints->min_width=minw;
-          SizeHints->min_height=minh;
-      } else {
-          SizeHints->flags=PMaxSize;
-      }
-      SizeHints->max_width=mwidth;
-      SizeHints->max_height=mheight;
+    if ( ! m_size_hints ) {
+        m_size_hints = XAllocSizeHints();
+    }
 
-      XSetWMNormalHints(dsp,win,SizeHints);
-      XFree(SizeHints);
-  }
+    if ( m_size_hints ) {
+        if ( minw >= 0 ) {
+            m_size_hints->flags |= PMaxSize | PMinSize;
+            m_size_hints->min_width = minw;
+            m_size_hints->min_height = minh;
+        } else {
+            m_size_hints->flags |= PMaxSize;
+        }
+        m_size_hints->max_width = mwidth;
+        m_size_hints->max_height = mheight;
 
-  maxw=mwidth;
-  maxh=mheight;
+        XSetWMNormalHints( dsp, win, m_size_hints );
+    }
+
+    maxw = mwidth;
+    maxh = mheight;
 }
 
 void AWindow::setMinSize(int mwidth,int mheight)
 {
-  XSizeHints *SizeHints;
-  Display *dsp=_aguix->getDisplay();
-  SizeHints=XAllocSizeHints();
+    Display *dsp = _aguix->getDisplay();
 
-  if ( SizeHints ) {
-      if(maxw>=0) {
-          SizeHints->flags=PMaxSize|PMinSize;
-          SizeHints->max_width=maxw;
-          SizeHints->max_height=maxh;
-      } else {
-          SizeHints->flags=PMinSize;
-      }
-      SizeHints->min_width=mwidth;
-      SizeHints->min_height=mheight;
+    if ( ! m_size_hints ) {
+        m_size_hints = XAllocSizeHints();
+    }
 
-      XSetWMNormalHints(dsp,win,SizeHints);
-      XFree(SizeHints);
-  }
+    if ( m_size_hints ) {
+        if ( maxw >= 0 ) {
+            m_size_hints->flags |= PMaxSize | PMinSize;
+            m_size_hints->max_width = maxw;
+            m_size_hints->max_height = maxh;
+        } else {
+            m_size_hints->flags |= PMinSize;
+        }
+        m_size_hints->min_width = mwidth;
+        m_size_hints->min_height = mheight;
 
-  minw=mwidth;
-  minh=mheight;
+        XSetWMNormalHints( dsp, win, m_size_hints );
+    }
+
+    minw = mwidth;
+    minh = mheight;
 }
 
 void AWindow::show()
@@ -192,6 +202,37 @@ void AWindow::show()
   Display *dsp=_aguix->getDisplay();
 
   XMapWindow(dsp,win);
+
+  if ( m_force_open_position &&
+       ( m_open_max_h || m_open_max_v ) ) {
+      // see
+      // https://specifications.freedesktop.org/wm-spec/wm-spec-1.3.html#idm140130317598336
+      XEvent ev;
+
+      memset( &ev, 0, sizeof( ev ) );
+      ev.type = ClientMessage;
+      ev.xclient.window = win;
+      ev.xclient.message_type = _aguix->getAtom( AGUIX::NET_WM_STATE );
+      ev.xclient.format = 32;
+      ev.xclient.data.l[0] = 1;
+
+      if ( m_open_max_h && m_open_max_v ) {
+          ev.xclient.data.l[1] = _aguix->getAtom( AGUIX::NET_WM_STATE_MAXIMIZED_HORZ );
+          ev.xclient.data.l[2] = _aguix->getAtom( AGUIX::NET_WM_STATE_MAXIMIZED_VERT );
+      } else if ( m_open_max_h ) {
+          ev.xclient.data.l[1] = _aguix->getAtom( AGUIX::NET_WM_STATE_MAXIMIZED_HORZ );
+          ev.xclient.data.l[2] = 0;
+      } else {
+          ev.xclient.data.l[1] = _aguix->getAtom( AGUIX::NET_WM_STATE_MAXIMIZED_VERT );
+          ev.xclient.data.l[2] = 0;
+      }
+
+      ev.xclient.data.l[3] = 1;
+      XSendEvent( dsp, DefaultRootWindow( _aguix->getDisplay() ),
+                  False, SubstructureRedirectMask,
+                  &ev);
+  }
+  
   onScreen=true;
   _aguix->xSync();
 }
@@ -973,7 +1014,6 @@ void AWindow::doCreateStuff()
   Visual *vis;
   unsigned long mask = CWEventMask | CWBackPixel | CWColormap;
   XSetWindowAttributes attr;
-  XSizeHints *SizeHints;
   XWMHints *WMHints;
 
   scr = _aguix->getScreen();
@@ -999,7 +1039,10 @@ void AWindow::doCreateStuff()
   attr.colormap = _aguix->getColormap();
   
   // create window
-  win = XCreateWindow( dsp, ParentWnd, _x, _y, _w, _h, 0, _aguix->getDepth(), InputOutput, vis, mask, &attr );
+  win = XCreateWindow( dsp, ParentWnd,
+                       m_force_open_position ? m_open_pos_x : _x,
+                       m_force_open_position ? m_open_pos_y : _y,
+                       _w, _h, 0, _aguix->getDepth(), InputOutput, vis, mask, &attr );
   if ( !win ) {
     return;
   }
@@ -1016,13 +1059,23 @@ void AWindow::doCreateStuff()
   XSetWMProtocols( dsp, win, _aguix->getCloseAtom(), 1 );
 
   // size of the window
-  SizeHints = XAllocSizeHints();
-  if ( SizeHints ) {
-      SizeHints->flags = PSize;
-      SizeHints->width = _w;
-      SizeHints->height = _h;
-      XSetWMNormalHints( dsp, win, SizeHints );
-      XFree( SizeHints );
+  if ( ! m_size_hints ) {
+      m_size_hints = XAllocSizeHints();
+  }
+
+  if ( m_size_hints ) {
+      m_size_hints->flags = PSize;
+      m_size_hints->width = _w;
+      m_size_hints->height = _h;
+
+      if ( m_force_open_position ) {
+          m_size_hints->flags |= USPosition;
+
+          m_size_hints->x = m_open_pos_x;
+          m_size_hints->y = m_open_pos_y;
+      }
+      
+      XSetWMNormalHints( dsp, win, m_size_hints );
   }
 
   // window grouping for window managers
@@ -1101,6 +1154,11 @@ void AWindow::doDestroyStuff()
       win = 0;
     }
     _aguix->Flush();
+
+    if ( m_size_hints ) {
+        XFree( m_size_hints );
+        m_size_hints = NULL;
+    }
   }
 
   onScreen = false;
@@ -1417,3 +1475,74 @@ void AWindow::updateCont()
         container->rearrange();
     }
 }
+
+int AWindow::isMaximized()
+{
+    Atom ret_type;
+    int ret_format;
+    unsigned long ret_len,ret_after;
+    unsigned char *ret_prop;
+
+    int res = 0;
+    
+    if ( _created == false ) return res;
+
+    if ( XGetWindowProperty( _aguix->getDisplay(),
+                             win,
+                             _aguix->getAtom( AGUIX::NET_WM_STATE ),
+                             0,
+                             32,
+                             False,
+                             AnyPropertyType,
+                             &ret_type,
+                             &ret_format,
+                             &ret_len,
+                             &ret_after,
+                             &ret_prop ) == Success ) {
+        if ( ret_len > 0 &&
+             ret_type == XA_ATOM &&
+             ret_format == 32 ) {
+            const Atom *atoms = (const Atom*)ret_prop;
+            for ( unsigned long i = 0; i < ret_len; i++ ) {
+                if ( atoms[i] == _aguix->getAtom( AGUIX::NET_WM_STATE_MAXIMIZED_HORZ ) ) {
+                    res |= 1;
+                } else if ( atoms[i] == _aguix->getAtom( AGUIX::NET_WM_STATE_MAXIMIZED_VERT ) ) {
+                    res |= 2;
+                }
+            }
+        }
+        XFree( ret_prop );
+    }
+
+    return res;
+}
+
+int AWindow::getRootPosition( int *x,
+                              int *y )
+{
+    Window child;
+
+    if ( _created == false ) return 1;
+
+    if ( XTranslateCoordinates( _aguix->getDisplay(),
+                                win,
+                                DefaultRootWindow( _aguix->getDisplay() ),
+                                0, 0,
+                                x, y,
+                                &child ) == True ) {
+        return 0;
+    }
+
+    return 1;
+}
+
+void AWindow::forceOpenPosition( int x, int y,
+                                 bool max_h,
+                                 bool max_v )
+{
+    m_open_pos_x = x;
+    m_open_pos_y = y;
+    m_open_max_h = max_h;
+    m_open_max_v = max_v;
+    m_force_open_position = true;
+}
