@@ -1,6 +1,6 @@
 /* awindow.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2015 Ralf Hoffmann.
+ * Copyright (C) 2001-2016 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -183,10 +183,22 @@ public:
   void forbidCallBacks();
   void permitCallBacks();
   bool callBackForbidden() const;
+  int isMaximized();
+
+  int getRootPosition( int *x,
+                       int *y );
+  void forceOpenPosition( int x, int y,
+                          bool max_h,
+                          bool max_v );
 protected:
   bool onScreen;
   int _bg;
   int maxw,maxh,minw,minh;
+
+  int m_open_pos_x, m_open_pos_y;
+  bool m_open_max_h, m_open_max_v;
+  bool m_force_open_position;
+  
   Window win;
   std::list<Window> subwins;
   int border;
@@ -197,6 +209,8 @@ protected:
   XIC inputcontext;
 #endif
   Requester *req;
+
+  XSizeHints *m_size_hints;
   
   int mapNr;
   AContainer *container;
