@@ -132,9 +132,10 @@ typedef AGCross AGEnterWindow;
 typedef AGCross AGLeaveWindow;
 
 typedef struct agbutton {
-  int type;
-  Button *button;
-  int state;
+    int type;
+    Button *button;
+    int state;       // 1 is left-click, 2 right-click, 3 and 4 mouse-wheel
+    int keystate;    // the state of the keyboard modifier keys
 } AGButton;
 
 typedef AGButton AGButtonPressed;
