@@ -1,6 +1,6 @@
 /* textview.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2013 Ralf Hoffmann.
+ * Copyright (C) 2005-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -43,9 +43,8 @@ TextView::TextView( AGUIX *parent,
 		    int y,
 		    int width,
 		    int height,
-		    int bg,
 		    std::string title,
-		    TextStorage &_ts ) : AWindow( parent, x, y, width, height, bg, title ),
+		    TextStorage &_ts ) : AWindow( parent, x, y, width, height, title ),
                                  ts( _ts ),
                                  tvcb( this ),
                                  _show_line_numbers( false ),
@@ -136,8 +135,8 @@ void TextView::createContainer()
   cont->resize( _w, _h );
   cont->rearrange();
 
-  hbar->setBG( 0 );
-  vbar->setBG( 0 );
+  hbar->setBG( _colors.getBackground() );
+  vbar->setBG( _colors.getBackground() );
 }
 
 void TextView::boxRedraw()
@@ -151,27 +150,27 @@ void TextView::boxRedraw()
   _aguix->FillRectangle( m_buffer, 0, 0, _w, _h );
 
   if ( m_show_frame ) {
-      _aguix->setFG( 0, 2 );
+      _aguix->setFG( 0, _aguix->getFaceCol_3d_bright() );
       _aguix->DrawLine( m_buffer, 0, 0, _w - 1, 0 );
       _aguix->DrawLine( m_buffer, 0, 0, 0, _h - 1 );
-      _aguix->setFG( 0, 1 );
+      _aguix->setFG( 0, _aguix->getFaceCol_3d_dark() );
       _aguix->DrawLine( m_buffer, 0, _h - 1, _w - 1, _h - 1 );
       _aguix->DrawLine( m_buffer, _w - 1, _h - 1, _w - 1, 1 );
   }
 
   if ( getDisplayFocus() == true ) {
     if ( getHasFocus() == true ) {
-      _aguix->setFG( 0, 2 );
+      _aguix->setFG( 0, _aguix->getFaceCol_3d_bright() );
     } else {
-      _aguix->setFG( 0, 1 );
+      _aguix->setFG( 0, _aguix->getFaceCol_3d_dark() );
     }
     _aguix->DrawLine( m_buffer, 1, _h - 2, _w - 2, _h - 2 );
     _aguix->DrawLine( m_buffer, _w - 2, _h - 2, _w - 2, 2 );
     
     if ( getHasFocus() == true ) {
-      _aguix->setFG( 0, 1 );
+      _aguix->setFG( 0, _aguix->getFaceCol_3d_dark() );
     } else {
-      _aguix->setFG( 0, 2 );
+      _aguix->setFG( 0, _aguix->getFaceCol_3d_bright() );
     }
     _aguix->DrawLine( m_buffer, 1, 1, _w - 2, 1 );
     _aguix->DrawLine( m_buffer, 1, 1, 1, _h - 2 );
@@ -692,7 +691,7 @@ void TextView::maximizeX( int max_width )
   resize( l, getHeight() );
 }
 
-void TextView::maximizeYLines( int max_lines )
+void TextView::maximizeYLines( int max_lines, int width )
 {
   int l, elementHeight;
   int bw;
@@ -703,6 +702,14 @@ void TextView::maximizeYLines( int max_lines )
   
   bw = ( _display_focus == true ) ? 2 : 1;
 
+  if ( width > 0 ) {
+      if ( line_wrap == true ) {
+          ts.setLineLimit( width );
+      } else {
+          ts.setLineLimit( -1 );
+      }
+  }
+
   l = ts.getNrOfLines();
   if ( l > max_lines ) l = max_lines;
   l = ( l + 1 ) * elementHeight;
@@ -861,6 +868,13 @@ void TextView::setColors( const ColorDef &col )
 {
     _colors = col;
     setBG( _colors.getBackground() );
+
+    if ( hbar ) {
+        hbar->setBG( _colors.getBackground() );
+    }
+    if ( vbar ) {
+        vbar->setBG( _colors.getBackground() );
+    }
 }
 
 TextView::ColorDef TextView::getColors() const
@@ -870,12 +884,12 @@ TextView::ColorDef TextView::getColors() const
 
 void TextView::initColors()
 {
-    _colors.setTextColor( _aguix->getColorForName( "TextView::textcolor" ) );
-    _colors.setBackground( _aguix->getColorForName( "TextView::background" ) );
-    _colors.setHighlightedFG( _aguix->getColorForName( "TextView::highlightedfg" ) );
-    _colors.setHighlightedBG( _aguix->getColorForName( "TextView::highlightedbg" ) );
-    _colors.setSelectionFG( _aguix->getColorForName( "TextView::selectionfg" ) );
-    _colors.setSelectionBG( _aguix->getColorForName( "TextView::selectionbg" ) );
+    _colors.setTextColor( _aguix->getFaces().getColor( "textview-fg" ) );
+    _colors.setBackground( _aguix->getFaces().getColor( "textview-bg" ) );
+    _colors.setHighlightedFG( _aguix->getFaces().getColor( "textview-highlight-fg" ) );
+    _colors.setHighlightedBG( _aguix->getFaces().getColor( "textview-highlight-bg" ) );
+    _colors.setSelectionFG( _aguix->getFaces().getColor( "textview-selection-fg" ) );
+    _colors.setSelectionBG( _aguix->getFaces().getColor( "textview-selection-bg" ) );
     setBG( _colors.getBackground() );
 }
 
@@ -1170,6 +1184,7 @@ std::pair< int, int > TextView::getTextPosForMousePos( int x, int y )
 
     int base_x = x - bw;
     base_x -= getTextStartOffset();
+    base_x += hbar->getOffset();
 
     if ( base_x < 0 ) base_x = 0;
 
