@@ -1,6 +1,6 @@
 /* changelayoutop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009-2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2009-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -192,7 +192,7 @@ ChangeLayoutOp::configure()
     tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) +
                               strlen( getDescription() ) + 1 );
     sprintf( tstr, catalog.getLocale( 293 ), getDescription() );
-    m_win = new AWindow( m_aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+    m_win = new AWindow( m_aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
     m_win->create();
     _freesafe(tstr);
     
@@ -250,7 +250,7 @@ ChangeLayoutOp::configure()
                              0, 0,
                              NULL, NULL );
     
-    m_ac1->add( new Text( m_aguix, 0, 0, catalog.getLocale( 565 ), 1 ), 0, 1, AContainer::CO_INCWNR );
+    m_ac1->add( new Text( m_aguix, 0, 0, catalog.getLocale( 565 ) ), 0, 1, AContainer::CO_INCWNR );
     // sub container 2x2 for lister config
     m_ac2 = m_ac1->add( new AContainer( m_win, 2, 2 ), 0, 2 );
     m_ac2->setMaxSpace( 5 );
@@ -264,7 +264,6 @@ ChangeLayoutOp::configure()
                                                          ( m_bv == true ) ? 1 : 0,
                                                          catalog.getLocale( 567 ),
                                                          LABEL_RIGHT,
-                                                         1,
                                                          0 ), 0, 0, AContainer::CO_INCWNR );
     m_cb2 = (ChooseButton*)m_ac2->add( new ChooseButton( m_aguix,
                                                          0,
@@ -274,7 +273,6 @@ ChangeLayoutOp::configure()
                                                          ( m_lvv == true ) ? 1 : 0,
                                                          catalog.getLocale( 568 ),
                                                          LABEL_RIGHT,
-                                                         1,
                                                          0 ), 1, 0, AContainer::CO_INCWNR );
     
     setupExampleContainers();
@@ -298,7 +296,7 @@ ChangeLayoutOp::configure()
     m_available_elements_ac->setMaxSpace( 0 );
     m_available_elements_ac->setMinSpace( 0 );
     m_available_elements_ac->setBorderWidth( 0 );
-    m_available_elements_ac->add( new SolidButton( m_aguix, 0, 0, catalog.getLocale( 857 ), 1, 0, false ),
+    m_available_elements_ac->add( new SolidButton( m_aguix, 0, 0, catalog.getLocale( 857 ), false ),
                                   0, 0, AContainer::CO_FIX );
     m_available_elements_lv = (FieldListView*)m_available_elements_ac->add( new FieldListView( m_aguix, 0, 0, 100, 10, 0 ),
                                                                             0, 1, AContainer::CO_FIX );
@@ -309,7 +307,7 @@ ChangeLayoutOp::configure()
     m_used_elements_ac->setMaxSpace( 0 );
     m_used_elements_ac->setMinSpace( 0 );
     m_used_elements_ac->setBorderWidth( 0 );
-    m_used_elements_ac->add( new SolidButton( m_aguix, 0, 0, catalog.getLocale( 858 ), 1, 0, false ),
+    m_used_elements_ac->add( new SolidButton( m_aguix, 0, 0, catalog.getLocale( 858 ), false ),
                              0, 0, AContainer::CO_FIX );
     m_used_elements_lv = (FieldListView*)m_used_elements_ac->add( new FieldListView( m_aguix, 0, 0, 100, 10, 0 ),
                                                                   0, 1, AContainer::CO_FIX );
@@ -320,9 +318,9 @@ ChangeLayoutOp::configure()
     m_elements_example_ac1_2->setMaxSpace( 0 );
     m_elements_example_ac1_2->setMinSpace( 0 );
     m_elements_example_ac1_2->setBorderWidth( 0 );
-    m_add_element_b = (Button*)m_elements_example_ac1_2->add( new Button( m_aguix, 0, 0, catalog.getLocale( 859 ), 1, 0, 0 ),
+    m_add_element_b = (Button*)m_elements_example_ac1_2->add( new Button( m_aguix, 0, 0, catalog.getLocale( 859 ), 0 ),
                                                               0, 1, AContainer::CO_FIX );
-    m_remove_element_b = (Button*)m_elements_example_ac1_2->add( new Button( m_aguix, 0, 0, catalog.getLocale( 860 ), 1, 0, 0 ),
+    m_remove_element_b = (Button*)m_elements_example_ac1_2->add( new Button( m_aguix, 0, 0, catalog.getLocale( 860 ), 0 ),
                                                                  0, 3, AContainer::CO_FIX );
     m_elements_example_ac1_2->setMinHeight( 10, 0, 2 );
     m_elements_example_ac1_2->setMaxHeight( 10, 0, 2 );
@@ -334,13 +332,13 @@ ChangeLayoutOp::configure()
     weight_ac1->setMaxSpace( 5 );
     weight_ac1->setBorderWidth( 0 );
     
-    weight_ac1->add( new Text( m_aguix, 0, 0, catalog.getLocale( 861 ), 1 ), 0, 0, AContainer::CO_FIX );
-    m_left_weight_b = (SolidButton*)weight_ac1->add( new SolidButton( m_aguix, 0, 0, "000%", 1, 0, true ),
+    weight_ac1->add( new Text( m_aguix, 0, 0, catalog.getLocale( 861 ) ), 0, 0, AContainer::CO_FIX );
+    m_left_weight_b = (SolidButton*)weight_ac1->add( new SolidButton( m_aguix, 0, 0, "000%", true ),
                                                      1, 0, AContainer::CO_FIX );
     m_weight_sl = (Slider*)weight_ac1->add( new Slider( m_aguix, 0, 0, 10, 10, false, 0 ),
                                             2, 0, AContainer::CO_MIN );
     m_weight_sl->setMaxLen( 8 );
-    m_right_weight_b = (SolidButton*)weight_ac1->add( new SolidButton( m_aguix, 0, 0, "100%", 1, 0, true ),
+    m_right_weight_b = (SolidButton*)weight_ac1->add( new SolidButton( m_aguix, 0, 0, "100%", true ),
                                                       3, 0, AContainer::CO_FIX );
     
     int weight = m_layout.getListViewWeight();
@@ -356,7 +354,6 @@ ChangeLayoutOp::configure()
                                                                       ( m_layout.getWeightRelToActive() == true ) ? 1 : 0,
                                                                       catalog.getLocale( 908 ),
                                                                       LABEL_RIGHT,
-                                                                      1,
                                                                       0 ), 0, 6, AContainer::CO_INCWNR );
 
     AContainer *ac1_3 = m_ac1->add( new AContainer( m_win, 2, 1 ), 0, 7 );
@@ -367,15 +364,11 @@ ChangeLayoutOp::configure()
                                                   0,
                                                   0,
                                                   catalog.getLocale( 11 ),
-                                                  1,
-                                                  0,
                                                   0 ), 0, 0, AContainer::CO_FIX );
     Button *cb = (Button*)ac1_3->add( new Button( m_aguix,
                                                   0,
                                                   0,
                                                   catalog.getLocale( 8 ),
-                                                  1,
-                                                  0,
                                                   0 ), 1, 0, AContainer::CO_FIX );
 
     m_win->setDoTabCycling( true );
@@ -504,7 +497,7 @@ void ChangeLayoutOp::setupExampleContainers()
     m_button_example_ac->setMinSpace( 0 );
 
     while ( m_example_buttons.size() < 6 ) {
-        SolidButton *b = new SolidButton( m_aguix, 0, 0, 20, 5, "", 1, 0, 0 );
+        SolidButton *b = new SolidButton( m_aguix, 0, 0, 20, 5, "", 0 );
         b->setAcceptFocus( false );
         m_example_buttons.push_back( b );
     }
@@ -530,11 +523,11 @@ void ChangeLayoutOp::setupExampleContainers()
     m_listview_example_ac->setMinSpace( 0 );
 
     if ( m_listview_example_b1 == NULL ) {
-        m_listview_example_b1 = new SolidButton( m_aguix, 0, 0, 10, 10, "", 1, 0, 0 );
+        m_listview_example_b1 = new SolidButton( m_aguix, 0, 0, 10, 10, "", 0 );
         m_listview_example_b1->setAcceptFocus( false );
     }
     if ( m_listview_example_b2 == NULL ) {
-        m_listview_example_b2 = new SolidButton( m_aguix, 0, 0, 10, 10, "", 1, 0, 0 );
+        m_listview_example_b2 = new SolidButton( m_aguix, 0, 0, 10, 10, "", 0 );
         m_listview_example_b2->setAcceptFocus( false );
     }
 
@@ -576,28 +569,28 @@ void ChangeLayoutOp::setupElementsExample()
     m_elements_example_ac2->setMinSpace( 0 );
 
     if ( m_example_statebar_b == NULL ) {
-        m_example_statebar_b = new SolidButton( m_aguix, 0, 0, 100, 10, "", 1, 0, 0 );
+        m_example_statebar_b = new SolidButton( m_aguix, 0, 0, 100, 10, "", 0 );
         m_example_statebar_b->setAcceptFocus( false );
         m_win->add( m_example_statebar_b );
     }
     if ( m_example_clockbar_b == NULL ) {
-        m_example_clockbar_b = new SolidButton( m_aguix, 0, 0, 100, 10, "", 1, 0, 0 );
+        m_example_clockbar_b = new SolidButton( m_aguix, 0, 0, 100, 10, "", 0 );
         m_example_clockbar_b->setAcceptFocus( false );
         m_win->add( m_example_clockbar_b );
     }
     if ( m_listview_example2_b1 == NULL ) {
-        m_listview_example2_b1 = new SolidButton( m_aguix, 0, 0, 10, 10, "", 1, 0, 0 );
+        m_listview_example2_b1 = new SolidButton( m_aguix, 0, 0, 10, 10, "", 0 );
         m_listview_example2_b1->setAcceptFocus( false );
         m_win->add( m_listview_example2_b1 );
     }
     if ( m_listview_example2_b2 == NULL ) {
-        m_listview_example2_b2 = new SolidButton( m_aguix, 0, 0, 10, 10, "", 1, 0, 0 );
+        m_listview_example2_b2 = new SolidButton( m_aguix, 0, 0, 10, 10, "", 0 );
         m_listview_example2_b2->setAcceptFocus( false );
         m_win->add( m_listview_example2_b2 );
     }
 
     while ( m_example_buttons2.size() < 6 ) {
-        SolidButton *b = new SolidButton( m_aguix, 0, 0, 20, 5, "", 1, 0, 0 );
+        SolidButton *b = new SolidButton( m_aguix, 0, 0, 20, 5, "", 0 );
         b->setAcceptFocus( false );
         m_example_buttons2.push_back( b );
         m_win->add( b );
