@@ -1,6 +1,6 @@
 /* chtimecore.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2015 Ralf Hoffmann.
+ * Copyright (C) 2015-2016 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -226,59 +226,17 @@ int ChTimeCore::applyNewTime( const change_base_entry &ss1,
     return ( getCancel() == true ) ? 1 : 0;
 }
 
-static std::string timeToString( time_t t )
-{
-    char buf[128];
-    struct tm converted_tm = { 0 };
-
-    localtime_r( &t, &converted_tm );
-    
-    if ( strftime( buf, sizeof( buf ),
-                   "%Y-%m-%d %H:%M:%S", &converted_tm ) > 0 ) {
-        return std::string( buf );
-    }
-
-    return "";
-}
-
-static bool parseStringToTime( const std::string &time_string,
-                               time_t *return_time )
-{
-    struct tm parsed_tm = { 0 };
-    time_t converted_time;
-
-    parsed_tm.tm_isdst = -1;
-
-    if ( strptime( time_string.c_str(),
-                   "%Y-%m-%d %H:%M:%S",
-                   &parsed_tm ) == NULL ) {
-        return false;
-    }
-
-    converted_time = mktime( &parsed_tm );
-
-    if ( converted_time == (time_t)-1 ) {
-        return false;
-    }
-
-    if ( return_time ) {
-        *return_time = converted_time;
-    }
-
-    return true;
-}
-
 static int checkValidity( ChooseButton *mod_cb,
                            StringGadget *mod_sg,
                            ChooseButton *acc_cb,
                            StringGadget *acc_sg )
 {
     if ( mod_cb->getState() ) {
-        if ( ! parseStringToTime( mod_sg->getText(), NULL ) ) return 1;
+        if ( ! AGUIXUtils::parseStringToTime( mod_sg->getText(), NULL ) ) return 1;
     }
 
     if ( acc_cb->getState() ) {
-        if ( ! parseStringToTime( acc_sg->getText(), NULL ) ) return 2;
+        if ( ! AGUIXUtils::parseStringToTime( acc_sg->getText(), NULL ) ) return 2;
     }
 
     return 0;
@@ -318,7 +276,7 @@ int ChTimeCore::requestNewTime( const FileEntry &fe,
                                                                       "", LABEL_LEFT, 0 ),
                                                     1, 0, AContainer::CO_FIXNR );
     StringGadget *mod_time_sg = ac1_1->addWidget( new StringGadget( m_aguix, 0, 0, m_aguix->getTextWidth( "0000-00-00 00:00:00" ) + 16,
-                                                                    timeToString( current_mod_time ).c_str(), 0 ),
+                                                                    AGUIXUtils::timeToString( current_mod_time ).c_str(), 0 ),
                                                   2, 0, AContainer::CO_INCW );
     Button *mod_now_b = ac1_1->addWidget( new Button( m_aguix, 0, 0,
                                                       catalog.getLocale( 1102 ), 0 ),
@@ -334,7 +292,7 @@ int ChTimeCore::requestNewTime( const FileEntry &fe,
                                                                       "", LABEL_LEFT, 0 ),
                                                     1, 1, AContainer::CO_FIXNR );
     StringGadget *acc_time_sg = ac1_1->addWidget( new StringGadget( m_aguix, 0, 0, m_aguix->getTextWidth( "0000-00-00 00:00:00" ) + 16,
-                                                                    timeToString( current_acc_time ).c_str(), 0 ),
+                                                                    AGUIXUtils::timeToString( current_acc_time ).c_str(), 0 ),
                                                   2, 1, AContainer::CO_INCW );
     Button *acc_now_b = ac1_1->addWidget( new Button( m_aguix, 0, 0,
                                                       catalog.getLocale( 1102 ), 0 ),
@@ -388,12 +346,12 @@ int ChTimeCore::requestNewTime( const FileEntry &fe,
                     } else if ( msg->button.button == cb ) {
                         endmode = 3;
                     } else if ( msg->button.button == mod_now_b ) {
-                        std::string s1 = timeToString( time( NULL ) );
+                        std::string s1 = AGUIXUtils::timeToString( time( NULL ) );
 
                         mod_time_sg->setText( s1.c_str() );
                         change_mod_cb->setState( true );
                     } else if ( msg->button.button == acc_now_b ) {
-                        std::string s1 = timeToString( time( NULL ) );
+                        std::string s1 = AGUIXUtils::timeToString( time( NULL ) );
 
                         acc_time_sg->setText( s1.c_str() );
                         change_acc_cb->setState( true );
@@ -401,8 +359,8 @@ int ChTimeCore::requestNewTime( const FileEntry &fe,
                         Calendar cal( true );
                         time_t tempt;
 
-                        if ( parseStringToTime( mod_time_sg->getText(),
-                                                &tempt ) ) {
+                        if ( AGUIXUtils::parseStringToTime( mod_time_sg->getText(),
+                                                           &tempt ) ) {
                             cal.setInitialDate( tempt );
                         }
 
@@ -414,8 +372,8 @@ int ChTimeCore::requestNewTime( const FileEntry &fe,
                         Calendar cal( true );
                         time_t tempt;
 
-                        if ( parseStringToTime( acc_time_sg->getText(),
-                                                &tempt ) ) {
+                        if ( AGUIXUtils::parseStringToTime( acc_time_sg->getText(),
+                                                            &tempt ) ) {
                             cal.setInitialDate( tempt );
                         }
 
@@ -488,14 +446,14 @@ int ChTimeCore::requestNewTime( const FileEntry &fe,
         time_t new_mod_time;
         time_t new_acc_time;
 
-        if ( parseStringToTime( mod_time_sg->getText(),
-                                &new_mod_time ) == true ) {
+        if ( AGUIXUtils::parseStringToTime( mod_time_sg->getText(),
+                                            &new_mod_time ) == true ) {
             return_time->new_mod_time = new_mod_time;
             return_time->apply_mod_time = change_mod_cb->getState();
         }
 
-        if ( parseStringToTime( acc_time_sg->getText(),
-                                &new_acc_time ) == true ) {
+        if ( AGUIXUtils::parseStringToTime( acc_time_sg->getText(),
+                                            &new_acc_time ) == true ) {
             return_time->new_acc_time = new_acc_time;
             return_time->apply_acc_time = change_acc_cb->getState();
         }
