@@ -975,6 +975,42 @@ char *Datei::getRelativePath( const char *source, const char *destdir, bool use_
   return dupstring( erg.c_str() );
 }
 
+char *Datei::getRelativePathExt( const char *source,
+                                 const char *destdir,
+                                 bool use_realpath )
+{
+    char *erg[2] = { NULL, NULL };
+
+    if ( ! source || ! destdir ) return NULL;
+
+    erg[0] = getRelativePath( source, destdir, use_realpath );
+    if ( erg[0] == NULL ) {
+        return NULL;
+    }
+
+    if ( use_realpath ) {
+        std::string real_source = NWC::Path::get_real_path( source );
+        if ( ! real_source.empty() ) {
+            erg[1] = getRelativePath( real_source.c_str(),
+                                      destdir,
+                                      use_realpath );
+        }
+    }
+
+    if ( erg[1] == NULL ) {
+        return erg[0];
+    }
+
+    // if the relative path for the real_source is shorter, take this one
+    if ( strlen( erg[1] ) < strlen( erg[0] ) ) {
+        _freesafe( erg[0] );
+        return erg[1];
+    }
+
+    _freesafe( erg[1] );
+    return erg[0];
+}
+
 int Datei::putCharacter( int c )
 {
   unsigned char cf[1];
