@@ -1,6 +1,6 @@
 /* dirfiltersets.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2007-2014 Ralf Hoffmann.
+ * Copyright (C) 2007-2014,2016 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -53,12 +53,10 @@ DirFilterSettings::DirFilterSettings( const DirFilterSettings &other ) :
 }
 
 bool DirFilterSettings::check( const std::string &dirname,
-                               NWCEntrySelectionState &es )
+                               const NWC::FSEntry *e )
 {
     bool use = true;
 
-    const auto e = es.getNWCEntry();
-
     if ( e == NULL ) return false;
 
     if ( _show_hidden == false &&
@@ -84,16 +82,6 @@ bool DirFilterSettings::check( const std::string &dirname,
         }
     }
 
-    if ( use == true ) {
-        if ( m_generic_filter.get() != NULL &&
-             e->getBasename() != ".." ) {
-
-            if ( m_generic_filter->check( es ) == false ) {
-                use = false;
-            }
-        }
-    }
-
     if ( use == true ) {
         bool isIn;
         
@@ -117,6 +105,30 @@ bool DirFilterSettings::check( const std::string &dirname,
         }
     }
 
+    return use;
+}
+
+bool DirFilterSettings::check( const std::string &dirname,
+                               NWCEntrySelectionState &es )
+{
+    bool use = true;
+
+    const auto e = es.getNWCEntry();
+
+    if ( e == NULL ) return false;
+
+    use = check( dirname, e );
+
+    if ( use == true ) {
+        if ( m_generic_filter.get() != NULL &&
+             e->getBasename() != ".." ) {
+
+            if ( m_generic_filter->check( es ) == false ) {
+                use = false;
+            }
+        }
+    }
+
     if ( use == true && m_bookmark_filter != SHOW_ALL ) {
         if ( m_bookmark_filter == SHOW_ONLY_BOOKMARKS ) {
             if ( es.getBookmarkMatch() == FileEntry::NOT_IN_BOOKMARKS ) {
