@@ -31,10 +31,7 @@
 #include "wcfiletype.hh"
 #include "magic_db.hh"
 #include "worker.h"
-
-#ifndef MAXPATHLEN
-#define MAXPATHLEN 2048
-#endif
+#include "nwc_os.hh"
 
 class FEBookmarkInfo {
 public:
@@ -215,296 +212,11 @@ int FileEntry::readInfos( bool update )
 
 char *FileEntry::getDestination() const
 {
-  char *str=NULL,*tstr;
-  if((isLink==true)&&(fullname!=NULL)) {
-    tstr=(char*)_allocsafe((MAXPATHLEN+1)*sizeof(char));
-    int x = worker_readlink( fullname, tstr, MAXPATHLEN );
-    if(x>=0) {
-      tstr[x]=0;
-      str=dupstring(tstr);
+    char *str = NULL;
+    if ( isLink == true && fullname != NULL ) {
+        str = NWC::OS::getLinkTarget( fullname );
     }
-    _freesafe(tstr);
-  }
-  return str;
-}
-
-int FileEntry::writeDestination2Buf(char *buf,int size2,bool terminated)
-{
-  int x=-1;
-  if((isLink==true)&&(fullname!=NULL)) {
-    x = worker_readlink( fullname, buf, size2 );
-    if((terminated==true)&&(x>=0)) {
-      buf[x]=0;
-    }
-  }
-  return x;
-}
-
-void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerTypes::listcol_t> *dis )
-{
-  char *str=NULL;
-  struct tm *timeptr;
-  loff_t dissize, li;
-  bool sfds=false;
-  std::string s1;
-  int ost, x;
-  char nbuf[ A_BYTESFORNUMBER( loff_t ) ];
-  int cur_field;
-  
-  if ( ( lv == NULL ) || ( dis == NULL ) ) return;
-  
-  cur_field = 0;
-  for ( int i = 0; i < (int)dis->size(); i++ ) {
-    if ( i > 0 ) cur_field++;
-    
-    switch( (*dis)[i] ) {
-      case WorkerTypes::LISTCOL_NAME:
-        s1 = "";
-        if ( isLink == true ) {
-          if ( isCorrupt == true ) s1 += '!';
-          else {
-            if ( S_ISDIR( dstatbuf.mode ) ) s1 += '~';
-            else s1 += '@';
-          }
-        } else {
-          if ( S_ISDIR( statbuf.mode ) ) s1 += '/';
-          else if ( S_ISFIFO( statbuf.mode ) ) s1 += '|';
-          else if ( S_ISSOCK( statbuf.mode ) ) s1 += '=';
-          else if ( S_ISCHR( statbuf.mode ) ) s1 += '-';
-          else if ( S_ISBLK( statbuf.mode ) ) s1 += '+';
-          else if ( isExe() == true ) s1 += '*';
-          else s1 += ' ';
-        }
-	s1 += name;
-        
-        // I only set update_set for name to avoid the overhead for
-        // every field as the name is probably always visible
-        lv->setText( row, cur_field, s1, true );
-        break;
-      case WorkerTypes::LISTCOL_SIZE:
-      case WorkerTypes::LISTCOL_SIZEH:
-        if ( S_ISCHR( statbuf.mode ) ||
-             S_ISBLK( statbuf.mode ) ) {
-          x = (int)statbuf.rdev;
-          snprintf( nbuf, sizeof( nbuf ), "%d", x >> 8 );
-          s1 = nbuf;
-          s1 += ", ";
-          snprintf( nbuf, sizeof( nbuf ), "%3d", x & 0xff );
-          s1 += nbuf;
-          lv->setText( row, cur_field, s1 );
-        } else {
-          if ( ( isDir() == true ) &&
-               ( isLink == false ) &&
-               ( dirsize >= 0 ) ) dissize = dirsize;
-          else dissize = statbuf.size;
-  
-          if ( isDir() == true ) {
-            if ( ! ( ( isLink == false ) && ( dirsize >= 0 ) ) ) {
-              if(wconfig->getShowStringForDirSize()==true)
-                sfds=true;
-            }
-          }
-          if(sfds==true) {
-            s1 = wconfig->getStringForDirSize();
-            lv->setText( row, cur_field, s1 );
-          } else {
-              if ( (*dis)[i] == WorkerTypes::LISTCOL_SIZEH ) {
-                  s1 = AGUIXUtils::bytes_to_human_readable_f( dissize, 1, 0 );
-                  lv->setText( row, cur_field, s1 );
-              } else {
-                  MakeLong2NiceStr( dissize, s1 );
-                  lv->setText( row, cur_field, s1 );
-              }
-          }
-        }
-        break;
-      case WorkerTypes::LISTCOL_TYPE:
-        if ( filetype != NULL ) {
-          s1 = filetype->getName();
-        } else {
-          if ( isDir() == true ) {
-            // Dir
-            s1 = wconfig->getdirtype()->getName();
-          } else {
-            s1 = wconfig->getnotyettype()->getName();
-          }
-        }
-        lv->setText( row, cur_field, s1 );
-        break;
-      case WorkerTypes::LISTCOL_PERM:
-        s1 = getPermissionString();
-        lv->setText( row, cur_field, s1 );
-        break;
-      case WorkerTypes::LISTCOL_OWNER:
-        // will be 1 for Owner.group, 0 else
-        ost=wconfig->getOwnerstringtype();
-
-        s1 = ugdb->getUserNameS( statbuf.userid );
-        if(ost==1) {
-          s1 += '.';
-        } else {
-          s1 += " @ ";
-        }
-        s1 += ugdb->getGroupNameS( statbuf.groupid );
-        lv->setText( row, cur_field, s1 );
-        break;
-      case WorkerTypes::LISTCOL_DEST:
-        str = getDestination();
-        if ( str != NULL ) {
-          // only if there will be something to print
-          lv->setText( row, cur_field, str );
-          _freesafe( str );
-        } else {
-          lv->setText( row, cur_field, "" );
-        }
-        break;
-      case WorkerTypes::LISTCOL_MOD:
-        timeptr = localtime( &( statbuf.lastmod ) );
-
-        s1 = "";
-
-        wconfig->writeDateToString( s1, timeptr );
-
-        lv->setText( row, cur_field, s1 );
-        break;
-      case WorkerTypes::LISTCOL_ACC:
-        timeptr = localtime( &( statbuf.lastaccess ) );
-
-        s1 = "";
-
-        wconfig->writeDateToString( s1, timeptr );
-
-        lv->setText( row, cur_field, s1 );
-        break;
-      case WorkerTypes::LISTCOL_CHANGE:
-        timeptr = localtime( &( statbuf.lastchange ) );
-
-        s1 = "";
-
-        wconfig->writeDateToString( s1, timeptr );
-
-        lv->setText( row, cur_field, s1 );
-        break;
-      case WorkerTypes::LISTCOL_INODE:
-        li = (loff_t)statbuf.inode;
-	MakeLong2NiceStr( li, s1, false );
-        lv->setText( row, cur_field, s1 );
-        break;
-      case WorkerTypes::LISTCOL_NLINK:
-        li = (loff_t)statbuf.nlink;
-	MakeLong2NiceStr( li, s1, false );
-        lv->setText( row, cur_field, s1 );
-        break;
-      case WorkerTypes::LISTCOL_BLOCKS:
-        li = (loff_t)statbuf.blocks;
-	MakeLong2NiceStr( li, s1, false );
-        lv->setText( row, cur_field, s1 );
-        break;
-      default:
-        break;
-    }
-    cur_field++;
-  }
-
-  int fg[4] = { 1, 1, 1, 1 }, bg[4] = { 0, 0, 0, 0 };
-  int missing_colors = FileEntryCustomColor::ALL_COLORS;
-  int custom_color_set = m_colors.getCustomColorSet();
-  int override_color_set =  m_colors.getOverrideColorSet();
-
-  if ( override_color_set != 0 ) {
-      if ( override_color_set & FileEntryCustomColor::NORMAL ) {
-          m_colors.getOverrideColor( FileEntryCustomColor::NORMAL, &fg[0], &bg[0] );
-          missing_colors &= ~FileEntryCustomColor::NORMAL;
-      }
-      if ( override_color_set & FileEntryCustomColor::SELECT ) {
-          m_colors.getOverrideColor( FileEntryCustomColor::SELECT, &fg[1], &bg[1] );
-          missing_colors &= ~FileEntryCustomColor::SELECT;
-      }
-      if ( override_color_set & FileEntryCustomColor::ACTIVE ) {
-          m_colors.getOverrideColor( FileEntryCustomColor::ACTIVE, &fg[2], &bg[2] );
-          missing_colors &= ~FileEntryCustomColor::ACTIVE;
-      }
-      if ( override_color_set & FileEntryCustomColor::SELACT ) {
-          m_colors.getOverrideColor( FileEntryCustomColor::SELACT, &fg[3], &bg[3] );
-          missing_colors &= ~FileEntryCustomColor::SELACT;
-      }
-  }
-  if ( custom_color_set != 0 ) {
-      if ( ( custom_color_set & FileEntryCustomColor::NORMAL ) &&
-           ( missing_colors & FileEntryCustomColor::NORMAL ) ) {
-          m_colors.getCustomColor( FileEntryCustomColor::NORMAL, &fg[0], &bg[0] );
-          missing_colors &= ~FileEntryCustomColor::NORMAL;
-      }
-      if ( ( custom_color_set & FileEntryCustomColor::SELECT  ) &&
-           ( missing_colors & FileEntryCustomColor::SELECT ) ) {
-          m_colors.getCustomColor( FileEntryCustomColor::SELECT, &fg[1], &bg[1] );
-          missing_colors &= ~FileEntryCustomColor::SELECT;
-      }
-      if ( ( custom_color_set & FileEntryCustomColor::ACTIVE  ) &&
-           ( missing_colors & FileEntryCustomColor::ACTIVE ) ) {
-          m_colors.getCustomColor( FileEntryCustomColor::ACTIVE, &fg[2], &bg[2] );
-          missing_colors &= ~FileEntryCustomColor::ACTIVE;
-      }
-      if ( ( custom_color_set & FileEntryCustomColor::SELACT  ) &&
-           ( missing_colors & FileEntryCustomColor::SELACT ) ) {
-          m_colors.getCustomColor( FileEntryCustomColor::SELACT, &fg[3], &bg[3] );
-          missing_colors &= ~FileEntryCustomColor::SELACT;
-      }
-  }
-  if ( missing_colors != 0 ) {
-      if ( isDir() == true && isCorrupt == false ) {
-          if ( missing_colors & FileEntryCustomColor::NORMAL ) {
-              fg[0] = wconfig->getUnselDir( 0 );
-              bg[0] = wconfig->getUnselDir( 1 );
-          }
-          if ( missing_colors & FileEntryCustomColor::SELECT ) {
-              fg[1] = wconfig->getSelDir( 0 );
-              bg[1] = wconfig->getSelDir( 1 );
-          }
-          if ( missing_colors & FileEntryCustomColor::ACTIVE ) {
-              fg[2] = wconfig->getUnselDirAct( 0 );
-              bg[2] = wconfig->getUnselDirAct( 1 );
-          }
-          if ( missing_colors & FileEntryCustomColor::SELACT ) {
-              fg[3] = wconfig->getSelDirAct( 0 );
-              bg[3] = wconfig->getSelDirAct( 1 );
-          }
-      } else {
-          if ( missing_colors & FileEntryCustomColor::NORMAL ) {
-              if ( isCorrupt == true ) {
-                  fg[0] = 4;
-              } else {
-                  fg[0] = wconfig->getUnselFile( 0 );
-              }
-              bg[0] = wconfig->getUnselFile( 1 );
-          }
-          if ( missing_colors & FileEntryCustomColor::SELECT ) {
-              fg[1] = wconfig->getSelFile( 0 );
-              bg[1] = wconfig->getSelFile( 1 );
-          }
-          if ( missing_colors & FileEntryCustomColor::ACTIVE ) {
-              if ( isCorrupt == true ) {
-                  fg[2] = 4;
-              } else {
-                  fg[2] = wconfig->getUnselFileAct( 0 );
-              }
-              bg[2] = wconfig->getUnselFileAct( 1 );
-          }
-          if ( missing_colors & FileEntryCustomColor::SELACT ) {
-              fg[3] = wconfig->getSelFileAct( 0 );
-              bg[3] = wconfig->getSelFileAct( 1 );
-          }
-      }
-  }
-
-  lv->setFG( row, FieldListView::CC_NORMAL, fg[0] );
-  lv->setBG( row, FieldListView::CC_NORMAL, bg[0] );
-  lv->setFG( row, FieldListView::CC_SELECT, fg[1] );
-  lv->setBG( row, FieldListView::CC_SELECT, bg[1] );
-  lv->setFG( row, FieldListView::CC_ACTIVE, fg[2] );
-  lv->setBG( row, FieldListView::CC_ACTIVE, bg[2] );
-  lv->setFG( row, FieldListView::CC_SELACT, fg[3] );
-  lv->setBG( row, FieldListView::CC_SELACT, bg[3] );
+    return str;
 }
 
 const char *FileEntry::getPermissionString()
@@ -589,15 +301,6 @@ bool FileEntry::match( const char* pattern )
   return false;
 }
 
-void FileEntry::setLVC_DND( FieldListViewDND *lv, int row, const std::vector<WorkerTypes::listcol_t> *dis )
-{
-  if ( lv == NULL ) return;
-
-  setLVC( lv, row, dis );
-  lv->replacedndtext( row, name );
-  lv->setDataExt( row, new NMRowData( row, this, fullname ) );
-}
-
 loff_t FileEntry::size() const
 {
   return statbuf.size;
