@@ -1,6 +1,6 @@
 /* informationmode.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2009,2012-2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2009,2012-2013,2016 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -32,6 +32,7 @@
 #include <aguix/acontainer.h>
 #include <aguix/fieldlistview.h>
 #include <aguix/awindow.h>
+#include <aguix/util.h>
 #include "datei.h"
 #include "nwc_path.hh"
 
@@ -219,8 +220,6 @@ void InformationMode::showinfos()
   FileEntry *fe;
   int x2,len,len2;
   char buffer[1024],
-       buffer2[ MAXPATHLEN + 1024 + 2 * A_BYTESFORNUMBER( int ) ],  // I need space for realpath and also other stuff
-                                                                    // but this is enough
        rights[3][4],
        *tstr, *str;
   char *bstr2;
@@ -360,22 +359,24 @@ void InformationMode::showinfos()
     len=strlen(catalog.getLocale(180));
     len2=strlen(catalog.getLocale(214));
     for(x2=1;x2<3;x2++) if(strlen(catalog.getLocale(214+x2))>(size_t)len2) len2=strlen(catalog.getLocale(214+x2));
-    sprintf(buffer2,"%%%ds %%%ds %%s",len,len2);
+
+    std::string s1 = AGUIXUtils::formatStringToString( "%%%ds %%%ds %%s", len, len2 );
     
-    tstr=(char*)_allocsafe(strlen(buffer2)+
-                           strlen(catalog.getLocale(180))+
-                           strlen(catalog.getLocale(214))+
-                           strlen(catalog.getLocale(215))+
-                           strlen(catalog.getLocale(216))+
-                           4+1);   // don't need so much space but prevents more allocs or max-calculation
-    
-    sprintf(tstr,buffer2,catalog.getLocale(180),catalog.getLocale(214),rights[0]);
-    lv->setText( 7, 0, tstr);
-    sprintf(tstr,buffer2,"",catalog.getLocale(215),rights[1]);
-    lv->setText( 8, 0, tstr);
-    sprintf(tstr,buffer2,"",catalog.getLocale(216),rights[2]);
-    lv->setText( 9, 0, tstr);
-    _freesafe(tstr);
+    std::string s2 = AGUIXUtils::formatStringToString( s1.c_str(),
+                                                       catalog.getLocale( 180 ),
+                                                       catalog.getLocale( 214 ),
+                                                       rights[0] );
+    lv->setText( 7, 0, s2 );
+    s2 = AGUIXUtils::formatStringToString( s1.c_str(),
+                                           "",
+                                           catalog.getLocale( 215 ),
+                                           rights[1] );
+    lv->setText( 8, 0, s2 );
+    s2 = AGUIXUtils::formatStringToString( s1.c_str(),
+                                           "",
+                                           catalog.getLocale( 216 ),
+                                          rights[2] );
+    lv->setText( 9, 0, s2 );
     
     tstr = (char*)_allocsafe( strlen( "  %s %04o" ) +
                               strlen( catalog.getLocale( 527 ) ) +
@@ -418,42 +419,27 @@ void InformationMode::showinfos()
     timeptr = localtime( &( tvar ) );
     str = asctime( timeptr );
     str[ strlen( str ) - 1 ] = 0;
-    sprintf( buffer2, "%%%ds: %%s", len );
+
+    s1 = AGUIXUtils::formatStringToString( "%%%ds: %%s", len );
     
-    bufferlen = strlen( buffer2 ) +
-                len +
-                strlen( str ) + 1;
-    tstr = (char*)_allocsafe( bufferlen );
-    
-    snprintf( tstr, bufferlen, buffer2, catalog.getLocale( 162 ), str );
-    lv->setText( 15, 0, tstr );
-    _freesafe( tstr );
+    s2 = AGUIXUtils::formatStringToString( s1.c_str(), catalog.getLocale( 162 ), str );
+    lv->setText( 15, 0, s2 );
 
     tvar = fe->lastmod();
     timeptr = localtime( &( tvar ) );
     str = asctime( timeptr );
     str[ strlen( str ) - 1 ] = 0;
 
-    bufferlen = strlen( buffer2 ) +
-                len +
-                strlen( str ) + 1;
-    tstr = (char*)_allocsafe( bufferlen );
-    snprintf( tstr, bufferlen, buffer2, catalog.getLocale( 163 ), str );
-    lv->setText( 16, 0, tstr );
-    _freesafe( tstr );
+    s2 = AGUIXUtils::formatStringToString( s1.c_str(), catalog.getLocale( 163 ), str );
+    lv->setText( 16, 0, s2 );
 
     tvar = fe->lastchange();
     timeptr = localtime( &( tvar ) );
     str = asctime( timeptr );
     str[ strlen( str ) - 1 ] = 0;
 
-    bufferlen = strlen( buffer2 ) +
-                len +
-                strlen( str ) + 1;
-    tstr = (char*)_allocsafe( bufferlen );
-    snprintf( tstr, bufferlen, buffer2, catalog.getLocale( 164 ), str );
-    lv->setText( 17, 0, tstr );
-    _freesafe( tstr );
+    s2 = AGUIXUtils::formatStringToString( s1.c_str(), catalog.getLocale( 164 ), str );
+    lv->setText( 17, 0, s2 );
 
     tstr=(char*)_allocsafe(strlen("%s: %s")+
                            strlen(catalog.getLocale(185))+
@@ -462,18 +448,14 @@ void InformationMode::showinfos()
     lv->setText( 19, 0, tstr);
     _freesafe(tstr);
 
-    if(realpath(fe->fullname,buffer2)!=NULL) {
-      tstr=(char*)_allocsafe(strlen("%s: %s")+
-                             strlen(catalog.getLocale(186))+
-                             strlen(buffer2)+1);
-      sprintf(tstr,"%s: %s",catalog.getLocale(186),buffer2);
+    tstr = realpath( fe->fullname, NULL );
+    if ( tstr ) {
+      s2 = AGUIXUtils::formatStringToString( "%s: %s", catalog.getLocale( 186 ), tstr );
+      free( tstr );
     } else {
-      tstr=(char*)_allocsafe(strlen("%s: ???")+
-                             strlen(catalog.getLocale(186))+1);
-      sprintf(tstr,"%s: ???",catalog.getLocale(186));
+      s2 = AGUIXUtils::formatStringToString( "%s: ???", catalog.getLocale( 186 ) );
     }
-    lv->setText( 20, 0, tstr);
-    _freesafe(tstr);
+    lv->setText( 20, 0, s2 );
 
     if ( fe->isCorrupt == false ) {
       istr = dupstring( fe->fullname );
