@@ -1,6 +1,6 @@
 /* menutreeui.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013 Ralf Hoffmann.
+ * Copyright (C) 2013-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -71,7 +71,7 @@ void MenuTreeUI::show()
         twin = m_aguix->getTransientWindow();
     }
 
-    AWindow *mainwin = new AWindow( m_aguix, 10, 10, 50, 10, 0, catalog.getLocaleCom( 62 ) );
+    AWindow *mainwin = new AWindow( m_aguix, 10, 10, 50, 10, catalog.getLocaleCom( 62 ) );
     mainwin->create();
 
     if ( twin != NULL ) {
@@ -86,7 +86,7 @@ void MenuTreeUI::show()
     RefCount<AFontWidth> lencalc( new AFontWidth( m_aguix, NULL ) );
     TextStorageString help_ts( catalog.getLocale( 1007 ), lencalc );
     TextView *help_tv = (TextView*)maincont->add( new TextView( m_aguix,
-                                                                0, 0, 50, 80, 0, "", help_ts ),
+                                                                0, 0, 50, 80, "", help_ts ),
                                                   0, 0, AContainer::CO_INCW );
     help_tv->setLineWrap( true );
     help_tv->maximizeX( 500 );
@@ -107,9 +107,9 @@ void MenuTreeUI::show()
     subcont0->setMaxSpace( 5 );
     subcont0->setBorderWidth( 0 );
 
-    subcont0->add( new Text( m_aguix, 0, 0, catalog.getLocale( 1008 ), 1, 0 ),
+    subcont0->add( new Text( m_aguix, 0, 0, catalog.getLocale( 1008 ) ),
                    0, 0, AContainer::CO_FIX );
-    m_breadcrumb = (Text*)subcont0->add( new Text( m_aguix, 0, 0, "", 1, 0 ),
+    m_breadcrumb = (Text*)subcont0->add( new Text( m_aguix, 0, 0, "" ),
                                          1, 0, AContainer::CO_INCW );
 
     AContainer *subcont1 = maincont->add( new AContainer( mainwin, 3, 2 ),
@@ -118,7 +118,7 @@ void MenuTreeUI::show()
     subcont1->setMaxSpace( 5 );
     subcont1->setBorderWidth( 0 );
 
-    subcont1->add( new Text( m_aguix, 0, 0, catalog.getLocale( 1009 ), 1, 0 ),
+    subcont1->add( new Text( m_aguix, 0, 0, catalog.getLocale( 1009 ) ),
                    0, 0, AContainer::CO_INCW );
     m_lv = (FieldListView*)subcont1->add( new FieldListView( m_aguix, 0, 0, 200, 200,
                                                              0 ),
@@ -127,7 +127,7 @@ void MenuTreeUI::show()
     m_lv->setHBarState( 2 );
     m_lv->setVBarState( 2 );
 
-    subcont1->add( new Text( m_aguix, 0, 0, catalog.getLocale( 1010 ), 1, 0 ),
+    subcont1->add( new Text( m_aguix, 0, 0, catalog.getLocale( 1010 ) ),
                    1, 0, AContainer::CO_INCW );
     m_lv_help = (FieldListView*)subcont1->add( new FieldListView( m_aguix, 0, 0, 200, 200,
                                                                   0 ),
@@ -136,7 +136,7 @@ void MenuTreeUI::show()
     m_lv_help->setHBarState( 2 );
     m_lv_help->setVBarState( 2 );
 
-    subcont1->add( new Text( m_aguix, 0, 0, catalog.getLocale( 1014 ), 1, 0 ),
+    subcont1->add( new Text( m_aguix, 0, 0, catalog.getLocale( 1014 ) ),
                    2, 0, AContainer::CO_INCW );
     m_lv_key = (FieldListView*)subcont1->add( new FieldListView( m_aguix, 0, 0, 100, 200,
                                                                  0 ),
@@ -151,10 +151,10 @@ void MenuTreeUI::show()
     subcont3->setMaxSpace( 5 );
     subcont3->setBorderWidth( 0 );
 
-    subcont3->add( new Text( m_aguix, 0, 0, catalog.getLocale( 793 ), 1, 0 ),
+    subcont3->add( new Text( m_aguix, 0, 0, catalog.getLocale( 793 ) ),
                    0, 0, AContainer::CO_FIX );
     Text *filtertext = (Text*)subcont3->add( new Text( m_aguix, 0, 0,
-                                                   "", 1, 0 ),
+                                                       "" ),
                                          1, 0, AContainer::CO_INCW );
 
     AContainer *subcont2 = maincont->add( new AContainer( mainwin, 2, 1 ), 0, 4 );
@@ -166,15 +166,11 @@ void MenuTreeUI::show()
                                                       0,
                                                       0,
                                                       catalog.getLocale( 392 ),
-                                                      1,
-                                                      0,
                                                       0 ), 0, 0, AContainer::CO_FIX );
     Button *cancelb = (Button*)subcont2->add( new Button( m_aguix,
                                                           0,
                                                           0,
                                                           catalog.getLocale( 8 ),
-                                                          1,
-                                                          0,
                                                           0 ), 1, 0, AContainer::CO_FIX );
 
     mainwin->contMaximize( true );
@@ -184,12 +180,12 @@ void MenuTreeUI::show()
     maincont->readLimits();
     mainwin->contMaximize( true );
 
-    int tw = Worker::getKVPStore().getIntValue( "commandmenu-width",
-                                                mainwin->getWidth(),
-                                                10000 );
-    int th = Worker::getKVPStore().getIntValue( "commandmenu-height",
-                                                mainwin->getHeight(),
-                                                10000 );
+    int tw = Worker::getPersKVPStore().getIntValue( "commandmenu-width",
+                                                    mainwin->getWidth(),
+                                                    10000 );
+    int th = Worker::getPersKVPStore().getIntValue( "commandmenu-height",
+                                                    mainwin->getHeight(),
+                                                    10000 );
     mainwin->resize( tw, th );
 
     mainwin->show();
@@ -364,48 +360,51 @@ void MenuTreeUI::show()
                                 ( ( agmsg->key.key >= XK_BackSpace ) && ( agmsg->key.key <= XK_Escape ) ) ) {
                     } else if ( strlen( agmsg->key.keybuf ) > 0 ) {
                         std::string last_filter = current_filter;
-                        last_filter += agmsg->key.keybuf;
-                        //TODOif ( apply_filter( cur_infix ) > 0 ) {
-                        current_filter = last_filter;
+                        current_filter += agmsg->key.keybuf;
 
-                        filtertext->setText( current_filter.c_str() );
+                        if ( m_menu->setFilter( current_filter ) < 1 ) {
+                            // no match, revert filter
+                            current_filter = last_filter;
 
-                        m_menu->setFilter( filtertext->getText() );
+                            m_menu->setFilter( current_filter );
+                        } else {
+                            filtertext->setText( current_filter.c_str() );
 
-                        showMenu();
+                            showMenu();
 
-                        if ( ! current_filter.empty() ) {
-                            std::string prefix;
+                            if ( ! current_filter.empty() ) {
+                                std::string prefix;
 
-                            if ( m_menu->getCurrentNode()->getParent() != NULL ) {
-                                prefix = m_menu->createPath( "/" );
-                            }
-
-                            std::string filter = prefix;
-
-                            if ( ! filter.empty() ) {
-                                filter += "/";
-                            }
-                            filter += current_filter;
-    
-                            std::string best_hit = m_pdb->getBestHit( filter );
-
-                            for ( int row = 0; row < m_lv->getElements(); row++ ) {
-                                std::string fullname = prefix;
-                                if ( ! fullname.empty() ) {
-                                    fullname += "/";
+                                if ( m_menu->getCurrentNode()->getParent() != NULL ) {
+                                    prefix = m_menu->createPath( "/" );
                                 }
-                                fullname += m_lv->getText( row, 0 );
 
-                                std::string fullname_with_help = fullname;
-                                fullname += ";";
-                                fullname += m_lv_help->getText( row, 0 );;
+                                std::string filter = prefix;
 
-                                if ( best_hit == fullname ||
-                                     best_hit == fullname_with_help ) {
-                                    m_lv->setActiveRow( row );
-                                    m_lv->redraw();
-                                    break;
+                                if ( ! filter.empty() ) {
+                                    filter += "/";
+                                }
+                                filter += current_filter;
+    
+                                std::string best_hit = m_pdb->getBestHit( filter );
+
+                                for ( int row = 0; row < m_lv->getElements(); row++ ) {
+                                    std::string fullname = prefix;
+                                    if ( ! fullname.empty() ) {
+                                        fullname += "/";
+                                    }
+                                    fullname += m_lv->getText( row, 0 );
+
+                                    std::string fullname_with_help = fullname;
+                                    fullname += ";";
+                                    fullname += m_lv_help->getText( row, 0 );;
+
+                                    if ( best_hit == fullname ||
+                                         best_hit == fullname_with_help ) {
+                                        m_lv->setActiveRow( row );
+                                        m_lv->redraw();
+                                        break;
+                                    }
                                 }
                             }
                         }
@@ -473,10 +472,10 @@ void MenuTreeUI::show()
         }
     }
 
-    Worker::getKVPStore().setIntValue( "commandmenu-width",
-                                       mainwin->getWidth() );
-    Worker::getKVPStore().setIntValue( "commandmenu-height",
-                                       mainwin->getHeight() );
+    Worker::getPersKVPStore().setIntValue( "commandmenu-width",
+                                           mainwin->getWidth() );
+    Worker::getPersKVPStore().setIntValue( "commandmenu-height",
+                                           mainwin->getHeight() );
 
     delete mainwin;
 
