@@ -172,10 +172,12 @@ void NMExtList::createExtList( ListerMode *lm, ActionMessage *msg, bool rec )
 
   switch ( msg->mode ) {
     case ActionMessage::AM_MODE_SPECIAL:
-        ss1 = std::unique_ptr< NM_specialsourceExt >( new NM_specialsourceExt( msg->getFE() ) );
+        if ( msg->getFE() ) {
+            ss1 = std::unique_ptr< NM_specialsourceExt >( new NM_specialsourceExt( msg->getFE() ) );
 
-        if ( ss1 != NULL ) {
-            splist.push_back( *ss1 );
+            if ( ss1 != NULL ) {
+                splist.push_back( *ss1 );
+            }
         }
         break;
     case ActionMessage::AM_MODE_SPECIFIC_ENTRIES:
@@ -189,11 +191,13 @@ void NMExtList::createExtList( ListerMode *lm, ActionMessage *msg, bool rec )
         break;
     case ActionMessage::AM_MODE_DNDACTION:
         dm = msg->dndmsg;
-        ss1 = std::unique_ptr< NM_specialsourceExt >( new NM_specialsourceExt( dm->getFE() ) );
-        if ( ss1 != NULL ) {
-            splist.push_back( *ss1 );
+
+        if ( dm->getFE() ) {
+            ss1 = std::unique_ptr< NM_specialsourceExt >( new NM_specialsourceExt( dm->getFE() ) );
+            if ( ss1 != NULL ) {
+                splist.push_back( *ss1 );
+            }
         }
-        //      }
       break;
     case ActionMessage::AM_MODE_ONLYACTIVE:
       break;
@@ -241,7 +245,9 @@ int NMExtList::create_externfe_rec( const char *fullname, bool rec, const FileEn
 int NMExtList::createExtList( std::list< NM_specialsourceExt > &splist, bool rec )
 {
     for ( auto &ss1 : splist ) {
-        create_externfe_rec( ss1.entry()->fullname, rec, ss1.entry() );
+        if ( ss1.entry() ) {
+            create_externfe_rec( ss1.entry()->fullname, rec, ss1.entry() );
+        }
     }
 
     return 0;
