@@ -1,6 +1,6 @@
-/* nwc_path.cc
+/* nwc_os.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009,2012 Ralf Hoffmann.
+ * Copyright (C) 2009,2012,2016 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -136,5 +136,31 @@ namespace NWC {
             else resstr = dupstring( tstr );
             return resstr;
         }
+
+        char *getLinkTarget( const char *symlink )
+        {
+            if ( ! symlink ) return NULL;
+
+            char *buf = NULL;
+            ssize_t buf_size = 1024;
+
+            while ( 1 ) {
+                buf = (char*)_allocsafe( buf_size * sizeof( char ) );
+                ssize_t bytes = worker_readlink( symlink, buf, buf_size );
+                if ( bytes < 0 ) {
+                    _freesafe( buf );
+                    buf = NULL;
+                    break;
+                } else if ( bytes >= buf_size ) {
+                    _freesafe( buf );
+                    buf_size *= 2;
+                } else {
+                    buf[ bytes ] = '\0';
+                    break;
+                }
+            }
+
+            return buf;
+        }
     }
 }
