@@ -1139,8 +1139,7 @@ int PathJumpUI::post_filtering()
         }
 
         if ( ! prefix_filter.empty() &&
-             ! AGUIXUtils::starts_with( it1->m_path,
-                                        prefix_filter ) ) {
+             ! NWC::Path::is_prefix_dir( prefix_filter, it1->m_path ) ) {
             new_state = false;
         }
 
