@@ -1,6 +1,6 @@
 /* wconfig.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2015 Ralf Hoffmann.
+ * Copyright (C) 2001-2016 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -156,9 +156,6 @@ public:
   WCFiletype *getunknowntype();
   void applyLanguage();
   
-  int savesize(int w,int h);
-  int loadsize(int *w,int *h);
-  
   const char *getTerminalStr();
   void setListerBG(int);
   int getListerBG();
