@@ -1,6 +1,6 @@
 /* worker.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2015 Ralf Hoffmann.
+ * Copyright (C) 2001-2016 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -276,7 +276,12 @@ protected:
   AWindow *listerwin[2];
   AContainer *maincont;
   
-  int w,h;
+  int m_main_window_width, m_main_window_height;
+    int m_main_window_last_absolute_x;
+    int m_main_window_last_absolute_y;
+    bool m_main_window_last_maximized_x;
+    bool m_main_window_last_maximized_y;
+
   unsigned int curRows,curColumns;
   int pbanknr,bbanknr;
   
@@ -424,6 +429,8 @@ protected:
 
     void showButtonCommandHelp( int i, int j, int state );
 
+    void loadWindowGeometry();
+
     DeepPathStore m_path_store;
     std::unique_ptr< PersDeepPathStore > m_pers_path_store;
 
