@@ -1,6 +1,6 @@
 /* worker_commands.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2015 Ralf Hoffmann.
+ * Copyright (C) 2001-2016 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -220,6 +220,9 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 64:
       fpr = new ChangeColumnsOp();
       break;
+    case 65:
+      fpr = new ViewNewestFilesOp();
+      break;
     default:
       fpr=new DNDAction();
   }
@@ -294,6 +297,7 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if ( fpr->isName( CommandMenuOp::name ) == true ) type = 62;
   else if ( fpr->isName( ChTimeOp::name ) == true ) type = 63;
   else if ( fpr->isName( ChangeColumnsOp::name ) == true ) type = 64;
+  else if ( fpr->isName( ViewNewestFilesOp::name ) == true ) type = 65;
   return type;
 }
 
