@@ -1,6 +1,6 @@
 /* worker_locale.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2015 Ralf Hoffmann.
+ * Copyright (C) 2001-2016 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,8 +27,8 @@
 #include "nwc_path.hh"
 #include "datei.h"
 
-#define CATENTRY 1159
-#define CATCOMENTRY 65
+#define CATENTRY 1169
+#define CATCOMENTRY 66
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -1073,7 +1073,7 @@ match any font." );
   catalog[973]=dupstring( "%s (%ld:%02ld at current rate)" );
   catalog[974]=dupstring( "Path jump" );
   catalog[975]=dupstring( "List of allowed directories to track for path jump command.|All those directories and their sub-directories are allowed to store in a local database|to allow faster access to often used directories. It's a prefix comparison|so add a trailing slash if necessary to avoid mismatches." );
-  catalog[976]=dupstring( "Enter directory to allow to be tracked by the path jump command:" );
+  catalog[976]=dupstring( "Enter directory to allow it to be tracked by the path jump command:" );
   catalog[977]=dupstring( "Also show entries from bookmarks and persistent path store (Ctrl+a)" );
   catalog[978]=dupstring( "Match quality" );
   catalog[979]=dupstring( "String copied to clipboard:" );
@@ -1086,7 +1086,7 @@ match any font." );
   catalog[986]=dupstring( "All entries still exist, nothing to remove." );
   catalog[987]=dupstring( "Show hints" );
   catalog[988]=dupstring( "evaluate command" );
-  catalog[989]=dupstring( "Evalute an internally registered command" );
+  catalog[989]=dupstring( "Evaluate an internally registered command" );
   catalog[990]=dupstring( "Command:" );
   catalog[991]=dupstring( "Watch directories for changes" );
   catalog[992]=dupstring( "There is not enough space on target %s.|Free space is %s. Still continuing?" );
@@ -1096,7 +1096,7 @@ match any font." );
   catalog[996]=dupstring( "Panelize (keep window)" );
   catalog[997]=dupstring( "Switch mode" );
   catalog[998]=dupstring( "Configure mode" );
-  catalog[999]=dupstring( "Appy dialog type to X windows" );
+  catalog[999]=dupstring( "Apply dialog type to X windows" );
   catalog[1000]=dupstring( "Command not supported" );
   catalog[1001]=dupstring( "Flags without path are relative to base dir" );
   catalog[1002]=dupstring( "The target directory is a virtual directory. If you continue,|the files will be copied to|%s." );
@@ -1264,6 +1264,16 @@ The default value here is the active entry and it's already correctly protected!
   catalog[1156]=dupstring( "+1 day (Ctrl+d)" );
   catalog[1157]=dupstring( "+1 week (Ctrl+w)" );
   catalog[1158]=dupstring( "Reset" );
+  catalog[1159]=dupstring( "same day" );
+  catalog[1160]=dupstring( "Modified:" );
+  catalog[1161]=dupstring( "past" );
+  catalog[1162]=dupstring( "future" );
+  catalog[1163]=dupstring( "Results:" );
+  catalog[1164]=dupstring( "Results: scanning..." );
+  catalog[1165]=dupstring( "Waiting..." );
+  catalog[1166]=dupstring( "<Cursor up> to increase number of days" );
+  catalog[1167]=dupstring( "<Cursor down> to decrease number of days" );
+  catalog[1168]=dupstring( "In this window you see all files modified at the same day as the newest file in the current directory. The results can be viewed as a virtual directory in the main window. You can also select only specific entries to be panelized. Also, you may choose to list files modified more days in the past." );
 
 //  catalog[]=dupstring( "" );
   
@@ -1332,6 +1342,7 @@ The default value here is the active entry and it's already correctly protected!
   catalogcom[62]=dupstring( "Command menu" );
   catalogcom[63]=dupstring( "Change file time" );
   catalogcom[64]=dupstring( "Change columns" );
+  catalogcom[65]=dupstring( "View newest files" );
   
   catalogflag[0]=dupstring( "String requester" );
   catalogflag[1]=dupstring( "path" );
