@@ -414,7 +414,7 @@ int WPUContext::closeWin()
   return 0;
 }
 
-WPUContext::parse_com_str_t WPUContext::parse( const char *str1, std::string &return_str, int maxlen, bool quote )
+WPUContext::parse_com_str_t WPUContext::parse( const char *str1, std::string &return_str, int maxlen, bool quote, parse_persist_t persist )
 {
     parse_com_str_t res = PARSE_ERROR;
   
@@ -438,11 +438,13 @@ WPUContext::parse_com_str_t WPUContext::parse( const char *str1, std::string &re
         res = parseComStr( str1, maxlen,
                            quote, return_str);
 
-        if ( extlist[0] == NULL ||
-             extlist[0]->getSize() != old_size ) {
-            worker->storePathPersIfInProgress( fullname );
-        } else {
-            worker->storePathPersIfInProgress( NWC::Path::dirname( fullname ) );
+        if ( persist != PERSIST_NOTHING ) {
+            if ( extlist[0] == NULL ||
+                 extlist[0]->getSize() != old_size ) {
+                worker->storePathPersIfInProgress( fullname );
+            } else if ( persist == PERSIST_ALL ) {
+                worker->storePathPersIfInProgress( NWC::Path::dirname( fullname ) );
+            }
         }
     }
     return res;
@@ -911,7 +913,8 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
           /*execute tstr */
           std::string res_str;
 
-          if ( parse( tstr, res_str, a_max( EXE_STRING_LEN - 1024, 256 ) ) == PARSE_SUCCESS ) {
+          if ( parse( tstr, res_str, a_max( EXE_STRING_LEN - 1024, 256 ),
+                      true, PERSIST_FLAGS ) == PARSE_SUCCESS ) {
               _freesafe( tstr );
               tstr = dupstring( res_str.c_str() );
           } else {
@@ -977,7 +980,8 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
         if ( ignore == 0 ) {
           std::string res_str;
 
-          if ( parse( tstr, res_str, a_max( EXE_STRING_LEN - 1024, 256 ) ) == PARSE_SUCCESS ) {
+          if ( parse( tstr, res_str, a_max( EXE_STRING_LEN - 1024, 256 ),
+                      true, PERSIST_FLAGS ) == PARSE_SUCCESS ) {
               _freesafe( tstr );
               tstr = dupstring( res_str.c_str() );
           } else {
@@ -1047,7 +1051,7 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
       } else {
           std::string res_str;
 
-          if ( parse( ifp_lexbuf, res_str, a_max( EXE_STRING_LEN - 1024, 256 ), false ) == PARSE_SUCCESS ) {
+          if ( parse( ifp_lexbuf, res_str, a_max( EXE_STRING_LEN - 1024, 256 ), false, PERSIST_FLAGS ) == PARSE_SUCCESS ) {
               e->strval = dupstring( res_str.c_str() );
           } else {
               e->strval = dupstring( "0" );
